Crate doc_db

Crate doc_db 

Modules

mock

Structs

CommitOutcome
ConflictDetails
ConflictInfo
ConflictKey
Database
DocDbRequest
DocDbRevision
DocHandle
DocKey
DodbConfig
DodbConnection
RawStatement
RawStatementResult
Transaction
Trx
TrxControl

Enums

RawTransactionOutcome
TrxResult
Value
WriteOp

Constants

FN0_CONTROL_DODB_TENANT_ID
The tenant outside the normal eight-character base36 project namespace that is reserved for the fn0 control plane.

Traits

DbRequest
DocGet
Document
TrxRead

Functions

database
Creates the backend-neutral document database used by normal fn0 guests.
dodb_tenant_id
Converts fn0’s existing string project identity to its dodb tenant.
dodb_with_connection
integer_value
memory
project_tenant_id
Compatibility name for callers that describe this boundary as a project tenant lookup rather than a dodb-specific conversion.
semantic
semantic_with_config
text_value
turso
turso_with_config