database

Function database 

pub fn database() -> Database
Creates the backend-neutral document database used by normal fn0 guests.

The runtime supplies the endpoint and routes it through the semantic doc-db RPC boundary. The host backend is intentionally not part of this API.