TrxRead

Trait TrxRead 

pub trait TrxRead: Sized {
    type Output;

    // Required methods
    fn collect_keys(&self, keys: &mut Vec<DocKey>);
    async fn finalize(
        self,
        tx: &Trx,
        results: &mut IntoIter<Option<StoredDoc>>,
    ) -> Result<Self::Output>;
}

Required Associated Types

Required Methods

fn collect_keys(&self, keys: &mut Vec<DocKey>)

async fn finalize( self, tx: &Trx, results: &mut IntoIter<Option<StoredDoc>>, ) -> Result<Self::Output>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<A: TrxRead, B: TrxRead, C: TrxRead, D: TrxRead, E: TrxRead, F: TrxRead, G: TrxRead, H: TrxRead, I: TrxRead, J: TrxRead, K: TrxRead, L: TrxRead> TrxRead for (A, B, C, D, E, F, G, H, I, J, K, L)

Source

type Output = (<A as TrxRead>::Output, <B as TrxRead>::Output, <C as TrxRead>::Output, <D as TrxRead>::Output, <E as TrxRead>::Output, <F as TrxRead>::Output, <G as TrxRead>::Output, <H as TrxRead>::Output, <I as TrxRead>::Output, <J as TrxRead>::Output, <K as TrxRead>::Output, <L as TrxRead>::Output)

Source

fn collect_keys(&self, keys: &mut Vec<DocKey>)

Source

async fn finalize( self, tx: &Trx, results: &mut IntoIter<Option<StoredDoc>>, ) -> Result<Self::Output>

Source

impl<A: TrxRead, B: TrxRead, C: TrxRead, D: TrxRead, E: TrxRead, F: TrxRead, G: TrxRead, H: TrxRead, I: TrxRead, J: TrxRead, K: TrxRead> TrxRead for (A, B, C, D, E, F, G, H, I, J, K)

Source

type Output = (<A as TrxRead>::Output, <B as TrxRead>::Output, <C as TrxRead>::Output, <D as TrxRead>::Output, <E as TrxRead>::Output, <F as TrxRead>::Output, <G as TrxRead>::Output, <H as TrxRead>::Output, <I as TrxRead>::Output, <J as TrxRead>::Output, <K as TrxRead>::Output)

Source

fn collect_keys(&self, keys: &mut Vec<DocKey>)

Source

async fn finalize( self, tx: &Trx, results: &mut IntoIter<Option<StoredDoc>>, ) -> Result<Self::Output>

Source

impl<A: TrxRead, B: TrxRead, C: TrxRead, D: TrxRead, E: TrxRead, F: TrxRead, G: TrxRead, H: TrxRead, I: TrxRead, J: TrxRead> TrxRead for (A, B, C, D, E, F, G, H, I, J)

Source

type Output = (<A as TrxRead>::Output, <B as TrxRead>::Output, <C as TrxRead>::Output, <D as TrxRead>::Output, <E as TrxRead>::Output, <F as TrxRead>::Output, <G as TrxRead>::Output, <H as TrxRead>::Output, <I as TrxRead>::Output, <J as TrxRead>::Output)

Source

fn collect_keys(&self, keys: &mut Vec<DocKey>)

Source

async fn finalize( self, tx: &Trx, results: &mut IntoIter<Option<StoredDoc>>, ) -> Result<Self::Output>

Source

impl<A: TrxRead, B: TrxRead, C: TrxRead, D: TrxRead, E: TrxRead, F: TrxRead, G: TrxRead, H: TrxRead, I: TrxRead> TrxRead for (A, B, C, D, E, F, G, H, I)

Source

type Output = (<A as TrxRead>::Output, <B as TrxRead>::Output, <C as TrxRead>::Output, <D as TrxRead>::Output, <E as TrxRead>::Output, <F as TrxRead>::Output, <G as TrxRead>::Output, <H as TrxRead>::Output, <I as TrxRead>::Output)

Source

fn collect_keys(&self, keys: &mut Vec<DocKey>)

Source

async fn finalize( self, tx: &Trx, results: &mut IntoIter<Option<StoredDoc>>, ) -> Result<Self::Output>

Source

impl<A: TrxRead, B: TrxRead, C: TrxRead, D: TrxRead, E: TrxRead, F: TrxRead, G: TrxRead, H: TrxRead> TrxRead for (A, B, C, D, E, F, G, H)

Source

type Output = (<A as TrxRead>::Output, <B as TrxRead>::Output, <C as TrxRead>::Output, <D as TrxRead>::Output, <E as TrxRead>::Output, <F as TrxRead>::Output, <G as TrxRead>::Output, <H as TrxRead>::Output)

Source

fn collect_keys(&self, keys: &mut Vec<DocKey>)

Source

async fn finalize( self, tx: &Trx, results: &mut IntoIter<Option<StoredDoc>>, ) -> Result<Self::Output>

Source

impl<A: TrxRead, B: TrxRead, C: TrxRead, D: TrxRead, E: TrxRead, F: TrxRead, G: TrxRead> TrxRead for (A, B, C, D, E, F, G)

Source

type Output = (<A as TrxRead>::Output, <B as TrxRead>::Output, <C as TrxRead>::Output, <D as TrxRead>::Output, <E as TrxRead>::Output, <F as TrxRead>::Output, <G as TrxRead>::Output)

Source

fn collect_keys(&self, keys: &mut Vec<DocKey>)

Source

async fn finalize( self, tx: &Trx, results: &mut IntoIter<Option<StoredDoc>>, ) -> Result<Self::Output>

Source

impl<A: TrxRead, B: TrxRead, C: TrxRead, D: TrxRead, E: TrxRead, F: TrxRead> TrxRead for (A, B, C, D, E, F)

Source

type Output = (<A as TrxRead>::Output, <B as TrxRead>::Output, <C as TrxRead>::Output, <D as TrxRead>::Output, <E as TrxRead>::Output, <F as TrxRead>::Output)

Source

fn collect_keys(&self, keys: &mut Vec<DocKey>)

Source

async fn finalize( self, tx: &Trx, results: &mut IntoIter<Option<StoredDoc>>, ) -> Result<Self::Output>

Source

impl<A: TrxRead, B: TrxRead, C: TrxRead, D: TrxRead, E: TrxRead> TrxRead for (A, B, C, D, E)

Source

type Output = (<A as TrxRead>::Output, <B as TrxRead>::Output, <C as TrxRead>::Output, <D as TrxRead>::Output, <E as TrxRead>::Output)

Source

fn collect_keys(&self, keys: &mut Vec<DocKey>)

Source

async fn finalize( self, tx: &Trx, results: &mut IntoIter<Option<StoredDoc>>, ) -> Result<Self::Output>

Source

impl<A: TrxRead, B: TrxRead, C: TrxRead, D: TrxRead> TrxRead for (A, B, C, D)

Source

type Output = (<A as TrxRead>::Output, <B as TrxRead>::Output, <C as TrxRead>::Output, <D as TrxRead>::Output)

Source

fn collect_keys(&self, keys: &mut Vec<DocKey>)

Source

async fn finalize( self, tx: &Trx, results: &mut IntoIter<Option<StoredDoc>>, ) -> Result<Self::Output>

Source

impl<A: TrxRead, B: TrxRead, C: TrxRead> TrxRead for (A, B, C)

Source

type Output = (<A as TrxRead>::Output, <B as TrxRead>::Output, <C as TrxRead>::Output)

Source

fn collect_keys(&self, keys: &mut Vec<DocKey>)

Source

async fn finalize( self, tx: &Trx, results: &mut IntoIter<Option<StoredDoc>>, ) -> Result<Self::Output>

Source

impl<A: TrxRead, B: TrxRead> TrxRead for (A, B)

Source

type Output = (<A as TrxRead>::Output, <B as TrxRead>::Output)

Source

fn collect_keys(&self, keys: &mut Vec<DocKey>)

Source

async fn finalize( self, tx: &Trx, results: &mut IntoIter<Option<StoredDoc>>, ) -> Result<Self::Output>

Source

impl<A: TrxRead> TrxRead for (A,)

Source

type Output = (<A as TrxRead>::Output,)

Source

fn collect_keys(&self, keys: &mut Vec<DocKey>)

Source

async fn finalize( self, tx: &Trx, results: &mut IntoIter<Option<StoredDoc>>, ) -> Result<Self::Output>

Implementors

Source

impl<R> TrxRead for R
where R: DocGet,